@@ -4,8 +4,8 @@
 time_hdr
 ========
 
-With **@time_box**, you can decorate a function to be sandwiched between start
-time and end time messages like this:
+With **@time_box**, you can decorate a function to be sandwiched between
+start time and end time messages like this:
 
 :Example: decorate a function with time_box
 
@@ -30,53 +30,72 @@ time and end time messages like this:
 
 The time_hdr module contains two items:
 
-    1) StartStopHeader class with two functions that will repectively print
-       a starting time and ending time messages in a flower box (see
-       flower_box module in scottbrian_utils package).
-    2) a time_box decorator that wraps a function and uses the StartStopHeader
-       to print the starting and ending time messages.
+    1) StartStopHeader class with two functions that will repectively
+       print a starting time and ending time messages in a flower box
+       (see flower_box module in scottbrian_utils package).
+    2) a time_box decorator that wraps a function and uses the
+       StartStopHeader to print the starting and ending time messages.
 
 time_box imports functools, sys, datetime, wrapt, and types from typing
 
 """
-
+########################################################################
+# Standard Library
+########################################################################
 import functools
 from datetime import datetime
-from typing import Any, Callable, cast, Dict, NewType, Optional, \
-    Tuple, TypeVar, Union
+import re
+from typing import (Any, Callable, cast, NewType, Optional,
+                    TypeVar, Union)
 
 from typing import overload
 
-from wrapt.decorators import decorator  # type: ignore
+########################################################################
+# Third Party
+########################################################################
+from wrapt.decorators import decorator
 
+########################################################################
+# Local
+########################################################################
 from scottbrian_utils.flower_box import print_flower_box_msg
 
+########################################################################
+# type aliases
+########################################################################
 
+########################################################################
+# NewType
+########################################################################
 DT_Format = NewType('DT_Format', str)
 
 
+########################################################################
+# StartStopHeader
+########################################################################
 class StartStopHeader:
-    """Supports the time_box decorator.
+    """Provide support for the time_box decorator.
 
      Provides:
 
         1) a place to store the start time and end time
-        2) method print_start_msg to print the start header with the start time
-        3) method print_end_msg to print the end trailer with end time and
-           elapsed time
+        2) method print_start_msg to print the start header with the
+           start time
+        3) method print_end_msg to print the end trailer with end time
+           and elapsed time
 
-    While there might be some standalone uses for this class and its methods,
-    its intended use is by the time_box decorator described later in this
-    module.
+    While there might be some standalone uses for this class and its
+    methods, its intended use is by the time_box decorator described
+    later in this module.
     """
     default_dt_format: DT_Format = DT_Format('%a %b %d %Y %H:%M:%S')
 
     def __init__(self, func_name: str) -> None:
-        """Store the input func_name and set the start and end times to None.
+        """Store func_name and set the start and end times to None.
 
         Args:
-            func_name: The name of the function to appear in the start and
-                         stop messages
+            func_name: The name of the function to appear in the start
+                         and stop messages
         """
         self.func_name = func_name
         self.start_DT: datetime = datetime.max
@@ -87,12 +106,12 @@ class StartStopHeader:
         """Issue end time message in a flower box.
 
         The end message includes the current datetime and elapsed time
-        (calculated as the difference between the end time and the saved start
-        time - see the *print_start_msg* method).
+        (calculated as the difference between the end time and the saved
+        start time - see the *print_start_msg* method).
 
         Args:
-            dt_format: Specifies the datetime format to use in the end time
-                         message. The default is
+            dt_format: Specifies the datetime format to use in the end
+                         time message. The default is
                          StartStopHeader.default_dt_format.
             kwargs: Specifies the print arguments to use on the print
                       statement, such as *end*, *file*, or *flush*.
@@ -107,9 +126,9 @@ class StartStopHeader:
                         **kwargs: Any) -> None:
         """Issue start time message in a flower box.
 
-        The start message includes the current datetime which is also saved to
-        be used later to calculate the elapsed time for the *print_end_msg*
-        invocation.
+        The start message includes the current datetime which is also
+        saved to be used later to calculate the elapsed time for the
+        *print_end_msg* invocation.
 
         Args:
             dt_format: Specifies the datetime format to use in the start
@@ -155,38 +174,7 @@ def time_box(wrapped: F, *,
              dt_format: DT_Format = StartStopHeader.default_dt_format,
              time_box_enabled: Union[bool, Callable[..., bool]] = True,
              **kwargs: Any) -> F:
-    r"""Overloaded time_box function.
-
-    This overloaded function is needed strictly for mypy type checking.
-
-    Note that there is a *wrapped* parameter for this overloaded
-    function. This is the case where the time_box is called directly
-    without using the pie decorator style. For example:
-    def func(): pass
-    func = time_box(func, dt_format = my_dt_format)
-
-    What happens is the time_box call returns with a callable function that
-    is the wrapped function. This new function is assigned to *func*. When
-    *func* is called, the decorator function issues a starting time
-    message, calls the wrapped function (i.e., the original *func*), issues
-    the ending time message, and returns any return values that the wrapped
-    function returns.
-
-    Args:
-        wrapped: Any callable function that accepts optional positional
-                   and/or optional keyword arguments, and optionally returns a
-                   value. The default is None, which will be the case when
-                   the pie decorator version is used with any of the following
-                   arguments specified.
-        dt_format: Specifies the datetime format to use in the start
-                     time message. The default is
-                     StartStopHeader.default_dt_format.
-        time_box_enabled: Specifies whether the start and end messages
-                            should be issued (True) or not (False). The
-                            default is True.
-        kwargs: Specifies the print arguments to use on the print
-                      statement, such as *end*, *file*, or *flush*.
-    """
+    pass
 
 
 @overload
@@ -194,38 +182,7 @@ def time_box(*,
              dt_format: DT_Format = StartStopHeader.default_dt_format,
              time_box_enabled: Union[bool, Callable[..., bool]] = True,
              **kwargs: Any) -> Callable[[F], F]:
-    """Overloaded time_box function.
-
-    This overloaded function is needed strictly for mypy type checking.
-
-    Note that there is no *wrapped* parameter for this overloaded
-    function. This is the case where the time_box decorator call is coded as,
-    for example:
-    @time_box(dt_format = my_dt_format)
-    def func(): pass
-
-    This results in the equivalent of:
-    def func(): pass
-    func = time_box(dt_format = my_dt_format)(func)
-
-    What happens is the time_box call returns with a callable function that
-    specifies as input a callable, and this returned function is immediately
-    called with *func* as the argument. This then results in the assignment
-    of *func* to the decorator function that issues a starting time
-    message, calls the wrapped function (i.e., the original *func*), issues
-    the ending time message, and returns any return values that the wrapped
-    function returns.
-
-    Args:
-        dt_format: Specifies the datetime format to use in the start
-                     time message. The default is
-                     StartStopHeader.default_dt_format.
-        time_box_enabled: Specifies whether the start and end messages
-                            should be issued (True) or not (False). The
-                            default is True.
-        kwargs: Specifies the print arguments to use on the print
-                      statement, such as *end*, *file*, or *flush*.
-    """
+    pass
 
 
 def time_box(wrapped: Optional[F] = None, *,
@@ -234,20 +191,21 @@ def time_box(wrapped: Optional[F] = None, *,
              **kwargs: Any) -> F:
     """Decorator to wrap a function in start time and end time messages.
 
-    The time_box decorator can be invoked with or without arguments, and the
-    function being wrapped can optionally take arguments and optionally
-    return a value. The wrapt.decorator is used to preserve the wrapped
-    function introspection capabilities, and functools.partial is used to
-    handle the case where decorator arguments are specified. The examples
-    further below will help demonstrate the various ways in which the
-    time_box decorator can be used.
+    The time_box decorator can be invoked with or without arguments, and
+    the function being wrapped can optionally take arguments and
+    optionally return a value. The wrapt.decorator is used to preserve
+    the wrapped function introspection capabilities, and
+    functools.partial is used to handle the case where decorator
+    arguments are specified. The examples further below will help
+    demonstrate the various ways in which the time_box decorator can be
+    used.
 
     Args:
         wrapped: Any callable function that accepts optional positional
-                   and/or optional keyword arguments, and optionally returns a
-                   value. The default is None, which will be the case when
-                   the pie decorator version is used with any of the following
-                   arguments specified.
+                   and/or optional keyword arguments, and optionally
+                   returns a value. The default is None, which will be
+                   the case when the pie decorator version is used with
+                   any of the following arguments specified.
         dt_format: Specifies the datetime format to use in the start
                      time message. The default is
                      StartStopHeader.default_dt_format.
@@ -259,8 +217,8 @@ def time_box(wrapped: Optional[F] = None, *,
 
     Returns:
         A callable function that issues a starting time message, calls
-        the wrapped function, issues the ending time message, and returns any
-        return values that the wrapped function returns.
+        the wrapped function, issues the ending time message, and
+        returns any return values that the wrapped function returns.
 
 
     :Example: statically wrapping function with time_box
@@ -271,7 +229,8 @@ def time_box(wrapped: Optional[F] = None, *,
 
     >>> @time_box(time_box_enabled=_tbe)
     ... def func4a() -> None:
-    ...      print('this is sample text for _tbe = False static example')
+    ...      print('this is sample text for _tbe = False static '
+    ...            'example')
 
     >>> func4a()  # func4a is not wrapped by time box
     this is sample text for _tbe = False static example
@@ -345,10 +304,10 @@ def time_box(wrapped: Optional[F] = None, *,
     *************************************
 
     """
-    # ========================================================================
-    #  The following code covers cases where time_box is used with or without
-    #  parameters, and where the decorated function has or does not have
-    #  parameters.
+    # ==================================================================
+    #  The following code covers cases where time_box is used with or
+    #  without parameters, and where the decorated function has or does
+    #  not have parameters.
     #
     #     Here's an example of time_box without args:
     #         @time_box
@@ -360,8 +319,8 @@ def time_box(wrapped: Optional[F] = None, *,
     #             print('42')
     #         aFunc = time_box(aFunc)
     #
-    #     In fact, the above direct call can be coded as shown instead of using
-    #     the pie decorator style.
+    #     In fact, the above direct call can be coded as shown instead
+    #     of using the pie decorator style.
     #
     #     Here's an example of time_box with args:
     #         @time_box(end='\n\n')
@@ -373,10 +332,10 @@ def time_box(wrapped: Optional[F] = None, *,
     #             print('42')
     #         aFunc = time_box(end='\n\n')(aFunc)
     #
-    #     Note that this is a bit more tricky: time_box(end='\n\n') portion
-    #     results in a function being returned that takes as its first
-    #     argument the separate aFunc specification in parens that we see at
-    #     the end of the first portion.
+    #     Note that this is a bit more tricky: time_box(end='\n\n')
+    #     portion results in a function being returned that takes as its
+    #     first argument the separate aFunc specification in parens that
+    #     we see at the end of the first portion.
     #
     #     Note that we can also code the above as shown and get the same
     #     result.
@@ -386,17 +345,18 @@ def time_box(wrapped: Optional[F] = None, *,
     #             print('42')
     #         aFunc = time_box(aFunc, end='\n\n')
     #
-    #     What happens in the tricky case is time_box gets control and tests
-    #     whether aFunc was specified, and if not returns a call to
-    #     functools.partial which is the function that accepts the aFunc
-    #     specification and then calls time_box with aFunc as the first
-    #     argument with the end='\n\n' as the second argument as we now have
-    #     something that time_box can decorate.
+    #     What happens in the tricky case is time_box gets control and
+    #     tests whether aFunc was specified, and if not returns a call
+    #     to functools.partial which is the function that accepts the
+    #     aFunc specification and then calls time_box with aFunc as the
+    #     first argument with the end='\n\n' as the second argument as
+    #     we now have something that time_box can decorate.
     #
-    #     One other complication is that we are also using the wrapt.decorator
-    #     for the inner wrapper function which does some more smoke and
-    #     mirrors to ensure introspection will work as expected.
-    # ========================================================================
+    #     One other complication is that we are also using the
+    #     wrapt.decorator for the inner wrapper function which does some
+    #     more smoke and mirrors to ensure introspection will work as
+    #     expected.
+    # ==================================================================
 
     if wrapped is None:
         return cast(F, functools.partial(time_box, dt_format=dt_format,
@@ -405,8 +365,8 @@ def time_box(wrapped: Optional[F] = None, *,
 
     @decorator(enabled=time_box_enabled)  # type: ignore
     def wrapper(func_to_wrap: F, instance: Optional[Any],
-                args: Tuple[Any, ...],
-                kwargs2: Dict[str, Any]) -> Any:
+                args: tuple[Any, ...],
+                kwargs2: dict[str, Any]) -> Any:
         header = StartStopHeader(func_to_wrap.__name__)
         header.print_start_msg(dt_format=dt_format, **kwargs)
 
@@ -417,3 +377,79 @@ def time_box(wrapped: Optional[F] = None, *,
         return ret_value
 
     return cast(F, wrapper(wrapped))
+
+
+########################################################################
+# get_datetime_match_string
+########################################################################
+def get_datetime_match_string(format: str) -> str:
+    """Return a regex string to match a datetime string.
+
+    Args:
+        format: string used to format a datetime that is to be used to
+                  create a match string
+
+    Returns:
+        string that is to be used in a regex expression to match a
+        datetime string
+
+    """
+    match_str_a = r'(Sun|Mon|Tue|Wed|Thu|Fri|Sat)'
+    match_str_A = r'(Sunday|Monday|Tuesday|Wednesday|Thursday|Friday|Saturday)'
+    match_str_d = r'([0-2][0-9]|3[0-1])'
+    match_str_b = r'(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)'
+    match_str_B = (r'(January|February|March|April|May|June|July|August'
+                   r'|September|October|November|December)')
+    match_str_m = r'(0[1-9]|1[0-2])'
+    match_str_w = r'[0-6]'
+    match_str_y = r'[0-9]{2,2}'
+    match_str_Y = r'[1-9][0-9]{3,3}'
+
+    match_str_H = r'([0-1][0-9]|2[0-3])'
+    match_str_I = r'(0[1-9]|1[0-2])'
+    match_str_p = r'(AM|PM)'
+    match_str_M = r'[0-5][0-9]'
+    match_str_S = r'[0-5][0-9]'
+    match_str_f = r'[0-9]{6,6}'
+    match_str_z = r'[+-]' + f'{match_str_H}{match_str_M}'
+    match_str_Z = r'(UTC|GMT)([+-]' + f'({match_str_H}:{match_str_M}))*'
+    match_str_j = r'[0-3][0-9]{2,2}'
+    match_str_U = r'[0-5][0-9]'
+    match_str_W = r'[0-5][0-9]'
+    match_str_c = (f'{match_str_a} {match_str_b} ( [1-9]|[0-2][0-9]|3[0-1]) '
+                   f'{match_str_H}:{match_str_M}:{match_str_S} {match_str_Y}')
+    # match_str_x = f'{match_str_m}/{match_str_d}/{match_str_Y}'
+    match_str_x = f'{match_str_m}/{match_str_d}/{match_str_y}'
+    match_str_X = f'{match_str_H}:{match_str_M}:{match_str_S}'
+    match_str_G = match_str_Y
+    match_str_u = r'[1-7]'
+    match_str_V = r'(0[1-9]|[1-5][0-9])'
+
+    match_str = re.escape(format)
+    match_str = re.sub('%a', match_str_a, match_str)
+    match_str = re.sub('%A', match_str_A, match_str)
+    match_str = re.sub('%d', match_str_d, match_str)
+    match_str = re.sub('%b', match_str_b, match_str)
+    match_str = re.sub('%B', match_str_B, match_str)
+    match_str = re.sub('%m', match_str_m, match_str)
+    match_str = re.sub('%w', match_str_w, match_str)
+    match_str = re.sub('%y', match_str_y, match_str)
+    match_str = re.sub('%Y', match_str_Y, match_str)
+    match_str = re.sub('%H', match_str_H, match_str)
+    match_str = re.sub('%I', match_str_I, match_str)
+    match_str = re.sub('%p', match_str_p, match_str)
+    match_str = re.sub('%M', match_str_M, match_str)
+    match_str = re.sub('%S', match_str_S, match_str)
+    match_str = re.sub('%f', match_str_f, match_str)
+    match_str = re.sub('%z', match_str_z, match_str)
+    match_str = re.sub('%Z', match_str_Z, match_str)
+    match_str = re.sub('%j', match_str_j, match_str)
+    match_str = re.sub('%U', match_str_U, match_str)
+    match_str = re.sub('%W', match_str_W, match_str)
+    match_str = re.sub('%c', match_str_c, match_str)
+    match_str = re.sub('%x', match_str_x, match_str)
+    match_str = re.sub('%X', match_str_X, match_str)
+    match_str = re.sub('%G', match_str_G, match_str)
+    match_str = re.sub('%u', match_str_u, match_str)
+    match_str = re.sub('%V', match_str_V, match_str)
+    return match_str
