@@ -66,7 +66,7 @@ class ExcHook:
         self.exc_err_msg1 = ''
 
     def raise_exc_if_one(self) -> None:
-        """Raise and error is we have one.
+        """Raise an error is we have one.
 
         Raises:
             Exception: exc_msg
@@ -89,24 +89,6 @@ def thread_exc(monkeypatch: Any) -> Generator[ExcHook, None, None]:
         a thread exception handler
 
     """
-    # class ExcHook:
-    #     """ExcHook class."""
-    #     def __init__(self) -> None:
-    #         """Initialize the ExcHook class instance."""
-    #         self.exc_err_msg1 = ''
-    #
-    #     def raise_exc_if_one(self) -> None:
-    #         """Raise and error is we have one.
-    #
-    #         Raises:
-    #             Exception: exc_msg
-    #
-    #         """
-    #         if self.exc_err_msg1:
-    #             exc_msg = self.exc_err_msg1
-    #             self.exc_err_msg1 = ''
-    #             raise Exception(f'{exc_msg}')
-
     logger.debug(f'hook before: {threading.excepthook}')
     exc_hook = ExcHook()
 
@@ -174,53 +156,3 @@ def dt_format_arg(request: Any) -> str:
         The params values are returned one at a time
     """
     return cast(str, request.param)
-
-
-# from scottbrian_algo1.diag_msg import DiagMsg
-# # from threading import Thread  #, Event
-# from datetime import datetime
-# import time
-#
-#
-# # def ptm(*args, **kwargs):
-# #     """return time.
-# #
-# #     Returns:
-# #         time as str
-# #     """
-# #     current_time = datetime.now()
-# #     strtime = current_time.strftime("%H:%M:%S.%f")
-# #     a, *b = args
-# #     a = strtime + ' ' + str(a)
-# #     print(a, *b, **kwargs)
-# #     return
-#
-#
-# class TAlgoApp(AlgoApp):
-#     def __init__(self):
-#         """TAlgoApp init."""
-#
-#         # ptm('SBT TAlgoApp:__init__ entered')
-#         AlgoApp.__init__(self)
-#         # self.run_thread = Thread(target=self.run)
-#         # ptm('SBT TAlgoApp:__init__ exiting')
-#
-#     def run(self):
-#         ptm( 'SBT TAlgoApp: run entered')
-#         for i in range(5):
-#             time.sleep(1)
-#             if i == 3:
-#                 ptm('SBT TAlgoApp: about to call nextValidId')
-#                 self.nextValidId(1)
-#
-#
-#
-# @pytest.fixture(scope='session')
-# def diag_msg() -> "AlgoApp":
-#     """Instantiate and return an AlgoApp for testing.
-#
-#     Returns:
-#         An instance of AlgoApp
-#     """
-#     a_algo_app = TAlgoApp()
-#     return a_algo_app
